# image-analysis
Python-based software for XRD data analysis. Allows users to analyze SPEC data, raw XRD scan images, and reciprocal space-converted datasets.

## Roadmap for v0.1.0
- [ ] Basic GUI layout
- [ ] Ability to select a project directory that includes a SPEC file, images subdirectory (populated), and XML configuration files for a detector and an instrument
- [ ] Ability to load list of scans from a SPEC file
- [ ] Ability to load SPEC data columns from scan
- [ ] Ability to load raw images from scan as a 3D dataset
- [ ] Ability to load converted dataset from scan as a 3D dataset

## License
See [`LICENSE.txt`](https://github.com/henryjsmith12/image-analysis/blob/main/LICENSE) for more information.

## Author
[Henry Smith](https://www.linkedin.com/in/henry-smith-5956a0189/) - Co-op Student Technical at Argonne National Laboratory